==> tora_1.3.4.orig.tar.gz: tora-1.3.4/tosearchreplace.h <==
//***************************************************************************
/*
 * TOra - An Oracle Toolkit for DBA's and developers
 * Copyright (C) 2000-2001,2001 Underscore AB
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;  only version 2 of
 * the License is valid for this program.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 *      As a special exception, you have permission to link this program
 *      with the Oracle Client libraries and distribute executables, as long
 *      as you follow the requirements of the GNU GPL in regard to all of the
 *      software in the executable aside from Oracle client libraries.
 *
 *      Specifically you are not permitted to link this program with the
 *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
 *      And you are not permitted to distribute binaries compiled against
 *      these libraries without written consent from Underscore AB. Observe
 *      that this does not disallow linking to the Qt Free Edition.
 *
 * All trademarks belong to their respective owners.
 *
 ****************************************************************************/

#ifndef TOSEARCHREPLACE_H
#define TOSEARCHREPLACE_H

#include "tosearchreplaceui.h"
#include "tohelp.h"

class toListView;
class toMarkedText;
class toResultContentEditor;

class toSearchReplace : public toSearchReplaceUI, public toHelpContext {
  toMarkedText *Text;
  toListView *List;
  toResultContentEditor *Content;
  bool FromTop;

  int findIndex(const QString &str,int line,int col);
  void findPosition(const QString &str,int index,int &line,int &col);
  bool findString(const QString &str,int &startPos,int &endPos);
  void release(void);

public:
  toSearchReplace(QWidget *parent);

  void setTarget(toMarkedText *parent);
  void setTarget(toListView *parent);
  void setTarget(toResultContentEditor *parent);
  bool searchNextAvailable();
public slots:
  virtual void destroyed();
  virtual void replaceAll();
  virtual void replace();
  virtual void search();
  virtual void searchNext();
  virtual void searchChanged();
  virtual void displayHelp();
};

#endif

==> tora_1.3.14.1.orig.tar.gz: tora-1.3.14.1/tosearchreplace.h <==
//***************************************************************************
/*
 * TOra - An Oracle Toolkit for DBA's and developers
 * Copyright (C) 2003 Quest Software, Inc
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;  only version 2 of
 * the License is valid for this program.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 *      As a special exception, you have permission to link this program
 *      with the Oracle Client libraries and distribute executables, as long
 *      as you follow the requirements of the GNU GPL in regard to all of the
 *      software in the executable aside from Oracle client libraries.
 *
 *      Specifically you are not permitted to link this program with the
 *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
 *      And you are not permitted to distribute binaries compiled against
 *      these libraries without written consent from Quest Software, Inc.
 *      Observe that this does not disallow linking to the Qt Free Edition.
 *
 * All trademarks belong to their respective owners.
 *
 ****************************************************************************/

#ifndef TOSEARCHREPLACE_H
#define TOSEARCHREPLACE_H

#include "tosearchreplaceui.h"
#include "tohelp.h"
#include "toeditwidget.h"

class toListView;
class toMarkedText;
class toResultContentEditor;

class toSearchReplace : public toSearchReplaceUI, public toHelpContext, public toEditWidget::editHandler {
  Q_OBJECT

  toEditWidget *Target;
public:
  toSearchReplace(QWidget *parent);
  ~toSearchReplace()
  { toEditWidget::delHandler(this); }

  virtual void show();
  bool findString(const QString &text,int &pos,int &endPos);
  virtual void receivedFocus(toEditWidget *widget);
  virtual void lostFocus(toEditWidget *)
  { receivedFocus(NULL); }
  bool searchNextAvailable(void);
public slots:
  virtual void searchNext();
private slots:
  virtual void replaceAll();
  virtual void replace();
  virtual void search();
  virtual void searchChanged();
  virtual void displayHelp();
};

#endif
